@@ -1,7 +1,7 @@
 #include <stdlib.h>
 
-#include <kapp.h>
-#include <kstddirs.h>
+#include <tdeapplication.h>
+#include <kstandarddirs.h>
 
 #include <tdeconfig.h>
 #include <tqdatetime.h>
@@ -45,16 +45,16 @@ Referee::Referee( TQWidget *parent, const char *name, int Scheme, int Mode, Bitf
     fruit = new Fruit(board);
 
     monsters = new TQPtrList<Monster>;
-    monsters->setAutoDelete(TRUE);
+    monsters->setAutoDelete(true);
 
     monsterRect = new TQPtrList<TQRect>;
-    monsterRect->setAutoDelete(TRUE);
+    monsterRect->setAutoDelete(true);
 
     energizers = new TQPtrList<Energizer>;
-    energizers->setAutoDelete(TRUE);
+    energizers->setAutoDelete(true);
 
     energizerRect = new TQPtrList<TQRect>;
-    energizerRect->setAutoDelete(TRUE);
+    energizerRect->setAutoDelete(true);
 
     pacmanRect.setRect(0, 0, 0, 0);
     fruitRect.setRect(0, 0, 0, 0);
@@ -166,7 +166,7 @@ void Referee::timerEvent( TQTimerEvent *e )
 
     TQRect lastRect;
     int lastPix;
-    bool moved = FALSE;
+    bool moved = false;
     int eated = 0;
 
     if (e->timerId() == energizerTimer) {
@@ -174,7 +174,7 @@ void Referee::timerEvent( TQTimerEvent *e )
             lastRect = pix->rect(energizers->at(e)->position(), EnergizerPix);
             lastPix = energizers->at(e)->pix();
             if (energizers->at(e)->move()) {
-                moved = TRUE;
+                moved = true;
                 *energizerRect->at(e) = pix->rect(energizers->at(e)->position(), EnergizerPix);
                 if (lastPix == energizers->at(e)->pix() &&
                     lastRect == pix->rect(energizers->at(e)->position(), EnergizerPix))
@@ -186,7 +186,7 @@ void Referee::timerEvent( TQTimerEvent *e )
 
         for (int e = 0; e < board->energizers(); e++)
             if (!energizerRect->at(e)->isNull())
-                repaint(*energizerRect->at(e), FALSE);
+                repaint(*energizerRect->at(e), false);
 
         return;
     }
@@ -251,7 +251,7 @@ void Referee::timerEvent( TQTimerEvent *e )
         }
         if (pos == fruit->position() && fruit->state() == active) {
             fruit->setEaten(fruitScoreDurTicks[level]);
-            initFruit(FALSE);
+            initFruit(false);
             score(fruitScore[fruit->pix()]);
         }
     }
@@ -266,7 +266,7 @@ void Referee::timerEvent( TQTimerEvent *e )
         if (fruit->move()) {
             if (pos == fruit->position() && fruit->state() == active) {
                 fruit->setEaten(fruitScoreDurTicks[level]);
-                initFruit(FALSE);
+                initFruit(false);
                 score(fruitScore[fruit->pix()]);
             }
             if (fruit->state() != active && fruit->pix() >= 0)
@@ -291,7 +291,7 @@ void Referee::timerEvent( TQTimerEvent *e )
             lastBodyPix = m->body();
             lastEyesPix = m->eyes();
             if (m->move()) {
-                moved = TRUE;
+                moved = true;
                 *monsterRect->at(m->id()) = pix->rect(m->position(), MonsterPix);
                 if (lastBodyPix == m->body() && lastEyesPix == m->eyes() &&
                     lastRect == pix->rect(m->position(), MonsterPix))
@@ -326,14 +326,14 @@ void Referee::timerEvent( TQTimerEvent *e )
                 }
 
     if (!pacmanRect.isNull())
-        repaint(pacmanRect, FALSE);
+        repaint(pacmanRect, false);
 
     if (!fruitRect.isNull())
-        repaint(fruitRect, FALSE);
+        repaint(fruitRect, false);
 
     for (int m = 0; m < board->monsters(); m++)
         if (!monsterRect->at(m)->isNull())
-            repaint(*monsterRect->at(m), FALSE);
+            repaint(*monsterRect->at(m), false);
 
     if (board->points() == 0 && !gameState.testBit(Dying))
         levelUp();
@@ -390,18 +390,18 @@ void Referee::repaintFigures()
     }
 
     if (!pacmanRect.isNull())
-        repaint(pacmanRect, FALSE);
+        repaint(pacmanRect, false);
 
     if (!fruitRect.isNull())
-        repaint(fruitRect, FALSE);
+        repaint(fruitRect, false);
 
     for (int m = 0; m < board->monsters(); m++)
         if (!monsterRect->at(m)->isNull())
-            repaint(*monsterRect->at(m), FALSE);
+            repaint(*monsterRect->at(m), false);
 
     for (int e = 0; e < board->energizers(); e++)
         if (!energizerRect->at(e)->isNull())
-            repaint(*energizerRect->at(e), FALSE);
+            repaint(*energizerRect->at(e), false);
 
 }
 
@@ -634,14 +634,14 @@ void Referee::confScheme()
         newgroup.sprintf("Mode %d", mode);
         kapp->config()->setGroup(newgroup);     
 
-        confLevels(FALSE);
+        confLevels(false);
     }
 
     if (scheme != -1) {
         newgroup.sprintf("Scheme %d", scheme);
         kapp->config()->setGroup(newgroup);     
 
-        confLevels(FALSE);
+        confLevels(false);
     }
 
     kapp->config()->setGroup(oldgroup);
@@ -654,18 +654,18 @@ void Referee::confScheme()
         newgroup.sprintf("Mode %d", mode);
         kapp->config()->setGroup(newgroup);     
 
-        confMisc(FALSE);
-        confTiming(FALSE);
-        confScoring(FALSE);
+        confMisc(false);
+        confTiming(false);
+        confScoring(false);
     }
 
     if (scheme != -1) {
         newgroup.sprintf("Scheme %d", scheme);
         kapp->config()->setGroup(newgroup);
 
-        confMisc(FALSE);
-        confTiming(FALSE);
-        confScoring(FALSE);
+        confMisc(false);
+        confTiming(false);
+        confScoring(false);
     }
 
     fillMapName();
@@ -721,7 +721,7 @@ void Referee::keyPressEvent( TQKeyEvent *k )
 
 #ifdef CHEATS
     else if (key == Key_L) { printf("levelUp()\n"); levelUp(); }
-    else if (key == Key_F) { printf("fruit->move(TRUE)\n"); fruit->move(TRUE); repaint(FALSE); }
+    else if (key == Key_F) { printf("fruit->move(true)\n"); fruit->move(true); repaint(false); }
     else if (key == Key_E) { printf("setLifes(++lifes)\n"); emit setLifes(++lifes); }
 #endif
 
@@ -804,10 +804,10 @@ void Referee::pause()
         stop();
         stopEnergizer();
         gameState.setBit(Paused);
-        repaint(pix->rect((BoardWidth*BoardHeight)/2-BoardWidth, i18n("PAUSED")), FALSE);
+        repaint(pix->rect((BoardWidth*BoardHeight)/2-BoardWidth, i18n("PAUSED")), false);
     } else {
         gameState.clearBit(Paused);
-        repaint(pix->rect((BoardWidth*BoardHeight)/2-BoardWidth, i18n("PAUSED")), FALSE);
+        repaint(pix->rect((BoardWidth*BoardHeight)/2-BoardWidth, i18n("PAUSED")), false);
         if (pausedTimer) {
             pausedTimer = 0;
             start();
@@ -824,7 +824,7 @@ void Referee::intro()
     stopEnergizer();
     bool paused = gameState.testBit(Paused);
 
-    gameState.fill(FALSE);
+    gameState.fill(false);
     gameState.setBit(Introducing);
     gameState.setBit(Init);
 
@@ -863,7 +863,7 @@ void Referee::introMonster(int id)
     if (m->eyes() != -1)
         pix->draw(m->position(), RoomPix, EyesPix, m->eyes());
 
-    repaint(pix->rect(m->position(), MonsterPix), FALSE);
+    repaint(pix->rect(m->position(), MonsterPix), false);
     m->setPosition(OUT);
 }
 
@@ -872,43 +872,43 @@ void Referee::introPaint(int t)
     TQString pts;
 
     switch (t) {
-        case  0 : repaint(pix->draw(16, 6, RoomPix, i18n("CHARACTER"), WHITE, TQColor(), AlignLeft), FALSE);
-                  repaint(pix->draw(36, 6, RoomPix, i18n("/"), WHITE, TQColor(), AlignLeft), FALSE);
-                  repaint(pix->draw(40, 6, RoomPix, i18n("NICKNAME"), WHITE, TQColor(), AlignLeft), FALSE);
+        case  0 : repaint(pix->draw(16, 6, RoomPix, i18n("CHARACTER"), WHITE, TQColor(), AlignLeft), false);
+                  repaint(pix->draw(36, 6, RoomPix, i18n("/"), WHITE, TQColor(), AlignLeft), false);
+                  repaint(pix->draw(40, 6, RoomPix, i18n("NICKNAME"), WHITE, TQColor(), AlignLeft), false);
                   break;
         case  1 : introMonster(0);
                   break;
-        case  2 : repaint(pix->draw(16, 10, RoomPix, i18n("-SHADOW"), RED, TQColor(), AlignLeft), FALSE);
+        case  2 : repaint(pix->draw(16, 10, RoomPix, i18n("-SHADOW"), RED, TQColor(), AlignLeft), false);
                   break;
-        case  3 : repaint(pix->draw(38, 10, RoomPix, i18n("\"BLINKY\""), RED, TQColor(), AlignLeft), FALSE);
+        case  3 : repaint(pix->draw(38, 10, RoomPix, i18n("\"BLINKY\""), RED, TQColor(), AlignLeft), false);
                   break;
         case  4 : introMonster(1);
                   break;
-        case  5 : repaint(pix->draw(16, 16, RoomPix, i18n("-SPEEDY"), PINK, TQColor(), AlignLeft), FALSE);
+        case  5 : repaint(pix->draw(16, 16, RoomPix, i18n("-SPEEDY"), PINK, TQColor(), AlignLeft), false);
                   break;
-        case  6 : repaint(pix->draw(38, 16, RoomPix, i18n("\"PINKY\""), PINK, TQColor(), AlignLeft), FALSE);
+        case  6 : repaint(pix->draw(38, 16, RoomPix, i18n("\"PINKY\""), PINK, TQColor(), AlignLeft), false);
                   break;
         case  7 : introMonster(2);
                   break;
-        case  8 : repaint(pix->draw(16, 22, RoomPix, i18n("-BASHFUL"), CYAN, TQColor(), AlignLeft), FALSE);
+        case  8 : repaint(pix->draw(16, 22, RoomPix, i18n("-BASHFUL"), CYAN, TQColor(), AlignLeft), false);
                   break;
-        case  9 : repaint(pix->draw(38, 22, RoomPix, i18n("\"INKY\""), CYAN, TQColor(), AlignLeft), FALSE);
+        case  9 : repaint(pix->draw(38, 22, RoomPix, i18n("\"INKY\""), CYAN, TQColor(), AlignLeft), false);
                   break;
         case 10 : introMonster(3);
                   break;
-        case 11 : repaint(pix->draw(16, 28, RoomPix, i18n("-POKEY"), ORANGE, TQColor(), AlignLeft), FALSE);
+        case 11 : repaint(pix->draw(16, 28, RoomPix, i18n("-POKEY"), ORANGE, TQColor(), AlignLeft), false);
                   break;
-        case 12 : repaint(pix->draw(38, 28, RoomPix, i18n("\"CLYDE\""), ORANGE, TQColor(), AlignLeft), FALSE);
+        case 12 : repaint(pix->draw(38, 28, RoomPix, i18n("\"CLYDE\""), ORANGE, TQColor(), AlignLeft), false);
                   break;
         case 13 : pts.sprintf("%d", pointScore);
-                  repaint(pix->draw(28, 44, RoomPix, pts, WHITE, TQColor(), AlignRight), FALSE);
-                  repaint(pix->draw(31, 44, RoomPix, "\x1C\x1D\x1E", WHITE, TQColor(), AlignLeft), FALSE);
+                  repaint(pix->draw(28, 44, RoomPix, pts, WHITE, TQColor(), AlignRight), false);
+                  repaint(pix->draw(31, 44, RoomPix, "\x1C\x1D\x1E", WHITE, TQColor(), AlignLeft), false);
                   pts.sprintf("%d", energizerScore);
-                  repaint(pix->draw(28, 48, RoomPix, pts, WHITE, TQColor(), AlignRight), FALSE);
-                  repaint(pix->draw(31, 48, RoomPix, "\x1C\x1D\x1E", WHITE, TQColor(), AlignLeft), FALSE);
+                  repaint(pix->draw(28, 48, RoomPix, pts, WHITE, TQColor(), AlignRight), false);
+                  repaint(pix->draw(31, 48, RoomPix, "\x1C\x1D\x1E", WHITE, TQColor(), AlignLeft), false);
                   break;
         case 14 : // "@ 1980 MIDWAY MFG.CO."
-                  repaint(pix->draw(30, 58, RoomPix, "© 1998-2003 J.THÖNNISSEN", PINK), FALSE);
+                  repaint(pix->draw(30, 58, RoomPix, "© 1998-2003 J.THÖNNISSEN", PINK), false);
                   break;
     }
 }
@@ -960,14 +960,14 @@ void Referee::introPlay()
     switch (timerCount) {
         case 13 : board->set(44*BoardWidth+22, Point);
                   pix->drawPoint(44*BoardWidth+22);
-                  repaint(pix->rect(44*BoardWidth+22, PointPix), FALSE);
+                  repaint(pix->rect(44*BoardWidth+22, PointPix), false);
                   energizers->at(0)->setPosition(48*BoardWidth+22);
                   energizers->at(0)->setOn();
-                  repaint(pix->rect(48*BoardWidth+22, EnergizerPix), FALSE);
+                  repaint(pix->rect(48*BoardWidth+22, EnergizerPix), false);
                   break;
         case 14 : energizers->at(1)->setPosition(36*BoardWidth+10);
                   energizers->at(1)->setOn();
-                  repaint(pix->rect(36*BoardWidth+10, EnergizerPix), FALSE);
+                  repaint(pix->rect(36*BoardWidth+10, EnergizerPix), false);
                   for (int pos = 8; pos < BoardWidth; pos++) {
                       board->set(34*BoardWidth+pos, out);
                       board->set(38*BoardWidth+pos, out);
@@ -976,7 +976,7 @@ void Referee::introPlay()
                   break;
         case 15 : gameState.clearBit(Init);
                   initPacman();
-                  pacman->setDemo(TRUE);
+                  pacman->setDemo(true);
                   pacman->setPosition(37*BoardWidth-1);
                   repaintFigures();
                   start();
@@ -1000,7 +1000,7 @@ void Referee::demo()
     stop();
     stopEnergizer();
 
-    gameState.fill(FALSE);
+    gameState.fill(false);
     gameState.setBit(Init);
     gameState.setBit(Demonstration);
 
@@ -1028,7 +1028,7 @@ void Referee::play()
     stop();
     stopEnergizer();
 
-    gameState.fill(FALSE);
+    gameState.fill(false);
     gameState.setBit(Init);
     gameState.setBit(Playing);
     gameState.setBit(Player);
@@ -1057,8 +1057,8 @@ void Referee::play()
     emit setLevel(level);
     emit setPoints(points);
 
-    repaint(pix->rect(board->position(monsterhome, 0), i18n("PLAYER ONE")), FALSE);
-    repaint(pix->rect(board->position(fruithome), i18n("READY!")), FALSE);
+    repaint(pix->rect(board->position(monsterhome, 0), i18n("PLAYER ONE")), false);
+    repaint(pix->rect(board->position(fruithome), i18n("READY!")), false);
 
     timerCount = 0;
     TQTimer::singleShot(playerDurMS, this, TQ_SLOT(ready()));
@@ -1075,7 +1075,7 @@ void Referee::ready()
         emit setLifes(--lifes);
         gameState.clearBit(Player);
         gameState.clearBit(Init);
-        repaint(pix->rect(board->position(monsterhome, 0), i18n("PLAYER ONE")), FALSE);
+        repaint(pix->rect(board->position(monsterhome, 0), i18n("PLAYER ONE")), false);
         repaintFigures();
         TQTimer::singleShot(playerDurMS, this, TQ_SLOT(ready()));
         return;
@@ -1083,12 +1083,12 @@ void Referee::ready()
 
     if (gameState.testBit(Ready)) {
         gameState.clearBit(Ready);
-        repaint(pix->rect(board->position(fruithome), i18n("READY!")), FALSE);
+        repaint(pix->rect(board->position(fruithome), i18n("READY!")), false);
         start();
     } else {
         gameState.setBit(Ready);
         gameState.clearBit(Init);
-        repaint(pix->rect(board->position(fruithome), i18n("READY!")), FALSE);
+        repaint(pix->rect(board->position(fruithome), i18n("READY!")), false);
         TQTimer::singleShot(readyDurMS, this, TQ_SLOT(ready()));
     }
 }
@@ -1208,7 +1208,7 @@ void Referee::killed()
     if (!gameState.testBit(Dying)) {
         gameState.setBit(Dying);
 
-        pacman->setDirection(X, TRUE);
+        pacman->setDirection(X, true);
         for (Monster *m = monsters->first(); m != 0; m = monsters->next())
             if (m)
                 m->setDirection(X);
@@ -1239,7 +1239,7 @@ void Referee::killedPlay()
     }
 
     if (timerCount <= pix->maxPixmaps(DyingPix)) {
-        repaint(pix->rect(pacman->position(), PacmanPix), FALSE);
+        repaint(pix->rect(pacman->position(), PacmanPix), false);
         if (timerCount >= pix->maxPixmaps(DyingPix)-1 || timerCount == 0)
             TQTimer::singleShot(dyingPostAnimationMS, this, TQ_SLOT(killedPlay()));
         else
@@ -1253,9 +1253,9 @@ void Referee::killedPlay()
             gameState.clearBit(Playing);
             for (int e = 0; e < board->energizers(); e++) {
                 energizers->at(e)->setOff();
-                repaint(pix->rect(board->position(energizer, e), EnergizerPix), FALSE);
+                repaint(pix->rect(board->position(energizer, e), EnergizerPix), false);
             }
-            repaint(pix->rect(board->position(fruithome), i18n("GAME  OVER")), FALSE);
+            repaint(pix->rect(board->position(fruithome), i18n("GAME  OVER")), false);
             TQTimer::singleShot(gameOverDurMS, this, TQ_SLOT(hallOfFame()));
         } else {
             gameState.clearBit(Init);
@@ -1275,7 +1275,7 @@ void Referee::initPacman()
     pacman->setMaxPixmaps(pix->maxPixmaps(PacmanPix));
     pacman->setDemo(gameState.testBit(Demonstration));
     pacman->setPosition(board->position(pacmanhome));
-    pacman->setDirection(W, TRUE);
+    pacman->setDirection(W, true);
     pacman->setAlive(pacmanTicks[level]);
 }
 
