@@ -1,8 +1,8 @@
 #include <stdlib.h>
 #include <ctype.h>
 
-#include <kapp.h>
-#include <kstddirs.h>
+#include <tdeapplication.h>
+#include <kstandarddirs.h>
 
 #include <tdeaccel.h>
 #include <tdeconfig.h>
@@ -21,7 +21,7 @@ Score::Score(TQWidget *parent, const char *name, int Scheme, int Mode, Bitfont *
 {
     setFocusPolicy(TQWidget::StrongFocus);
 
-    paused = FALSE;
+    paused = false;
 
     lastScore = -1;
     lastPlayer = -1;
@@ -30,7 +30,7 @@ Score::Score(TQWidget *parent, const char *name, int Scheme, int Mode, Bitfont *
     cursorBlinkMS = -1;
     cursor.x = -1;
     cursor.y = -1;
-    cursor.on = FALSE;
+    cursor.on = false;
     cursor.chr = TQChar('?');
 
     initKeys();
@@ -160,14 +160,14 @@ void Score::timerEvent(TQTimerEvent *e)
         return;
 
     if (cursor.x != -1 && cursor.y != -1)
-        repaint(rect(cursor.x, cursor.y*1.25, cursor.chr), FALSE);
-    scrollRepeat = FALSE;
+        repaint(rect(cursor.x, cursor.y*1.25, cursor.chr), false);
+    scrollRepeat = false;
 
     if (lastPlayer == 0)
-        repaint(rect(1, 0, i18n("  1UP ")), FALSE);
+        repaint(rect(1, 0, i18n("  1UP ")), false);
 
     if (lastPlayer == 1)
-        repaint(rect(21, 0, i18n("  2UP ")), FALSE);
+        repaint(rect(21, 0, i18n("  2UP ")), false);
 }
 
 void Score::keyPressEvent(TQKeyEvent *k)
@@ -236,15 +236,15 @@ void Score::keyPressEvent(TQKeyEvent *k)
     if (x != cursor.x || y != cursor.y) {
         if (cursor.x != -1)
             cursor.chr = hallOfFame[lastScore].name.at(cursor.x-14);
-        scrollRepeat = FALSE;
-        repaint(rect(x, y*1.25, cursor.chr), FALSE);
+        scrollRepeat = false;
+        repaint(rect(x, y*1.25, cursor.chr), false);
     } else
         hallOfFame[lastScore].name.at(cursor.x-14) = cursor.chr;
 
     if (key == UpKey || key == Key_Up || key == DownKey || key == Key_Down)
-       scrollRepeat = TRUE;
+       scrollRepeat = true;
     else
-       repaint(rect(cursor.x, cursor.y*1.25, cursor.chr), FALSE);
+       repaint(rect(cursor.x, cursor.y*1.25, cursor.chr), false);
 }
 
 void Score::initKeys()
@@ -304,14 +304,14 @@ void Score::confScheme()
         newgroup.sprintf("Mode %d", mode);
         kapp->config()->setGroup(newgroup);     
 
-        confTiming(FALSE);
+        confTiming(false);
     }
 
     if (scheme != -1) {
         newgroup.sprintf("Scheme %d", scheme);
         kapp->config()->setGroup(newgroup);
 
-        confTiming(FALSE);
+        confTiming(false);
     }
 
     if (cursorBlinkMS != oldCursorBlinkMS) {
@@ -365,12 +365,12 @@ void Score::set(int score, int player)
     TQString s;
 
     s.sprintf("%6d0", playerScore[lastPlayer]/10);
-    repaint(rect(0, 1, s), FALSE);
+    repaint(rect(0, 1, s), false);
 
     if (score > HighScore) {
             HighScore = score;
             s.sprintf("%8d0", HighScore/10);
-            repaint(rect(8, 1, s), FALSE);
+            repaint(rect(8, 1, s), false);
     }
 }
 
@@ -505,10 +505,10 @@ void Score::setPause(bool Paused)
 
     TQRect r = bitfont->rect(i18n("PAUSED"));
     r.moveCenter(TQPoint(this->width()/2, this->height()/2));
-    repaint(r, TRUE);
+    repaint(r, true);
 
     // repaint 1UP or 2UP
-    repaint(FALSE);
+    repaint(false);
 }
 
 void Score::end()
@@ -519,7 +519,7 @@ void Score::end()
     }
 
     // repaint 1UP or 2UP
-    repaint(FALSE);
+    repaint(false);
 
     // if lastPlayer != -1 we're already in playing mode
     if (lastPlayer == -1)
