@@ -47,16 +47,16 @@ TDEpacmanApp::TDEpacmanApp(TQWidget *, const char *name) : TDEMainWindow(0, name
   highscoresChecked = false;
   focusedPause = false;
 
-  connect(view->referee, SIGNAL(setScore(int, int)), view->score, SLOT(setScore(int, int)));
-  connect(view->referee, SIGNAL(setPoints(int)), view->score, SLOT(set(int)));
-  connect(view->referee, SIGNAL(setLifes(int)), view->status, SLOT(setLifes(int)));
-  connect(view->referee, SIGNAL(setLevel(int)), view->status, SLOT(setLevel(int)));
+  connect(view->referee, TQ_SIGNAL(setScore(int, int)), view->score, TQ_SLOT(setScore(int, int)));
+  connect(view->referee, TQ_SIGNAL(setPoints(int)), view->score, TQ_SLOT(set(int)));
+  connect(view->referee, TQ_SIGNAL(setLifes(int)), view->status, TQ_SLOT(setLifes(int)));
+  connect(view->referee, TQ_SIGNAL(setLevel(int)), view->status, TQ_SLOT(setLevel(int)));
 
-  connect(view->referee, SIGNAL(focusedGamePause()), this, SLOT(slotFocusedGamePause()));
-  connect(view->referee, SIGNAL(forcedGameHighscores()), this, SLOT(slotForcedGameHighscores()));
+  connect(view->referee, TQ_SIGNAL(focusedGamePause()), this, TQ_SLOT(slotFocusedGamePause()));
+  connect(view->referee, TQ_SIGNAL(forcedGameHighscores()), this, TQ_SLOT(slotForcedGameHighscores()));
 
-  connect(view->score, SIGNAL(gameHighscores()), this, SLOT(slotGameHighscores()));
-  connect(view->score, SIGNAL(gameFinished()), this, SLOT(slotGameFinished()));
+  connect(view->score, TQ_SIGNAL(gameHighscores()), this, TQ_SLOT(slotGameHighscores()));
+  connect(view->score, TQ_SIGNAL(gameFinished()), this, TQ_SLOT(slotGameFinished()));
 }
 
 TDEpacmanApp::~TDEpacmanApp()
@@ -67,25 +67,25 @@ TDEpacmanApp::~TDEpacmanApp()
 
 void TDEpacmanApp::initActions()
 {
-  gameNew = KStdGameAction::gameNew(this, SLOT(slotGameNew()), actionCollection());
-  gamePause = KStdGameAction::pause(this, SLOT(slotGamePause()), actionCollection());
+  gameNew = KStdGameAction::gameNew(this, TQ_SLOT(slotGameNew()), actionCollection());
+  gamePause = KStdGameAction::pause(this, TQ_SLOT(slotGamePause()), actionCollection());
   gamePause->setAccel(Key_F3);
-  gameQuit = KStdGameAction::quit(this, SLOT(slotGameQuit()), actionCollection());
-  gameHighscores = KStdGameAction::highscores(this, SLOT(slotGameHighscores()), actionCollection());
-  showMenuBar = KStdAction::showMenubar(this, SLOT(slotShowMenuBar()), actionCollection());
-  showToolBar = KStdAction::showToolbar(this, SLOT(slotShowToolBar()), actionCollection());
-  showStatusBar = KStdAction::showStatusbar(this, SLOT(slotShowStatusBar()), actionCollection());
+  gameQuit = KStdGameAction::quit(this, TQ_SLOT(slotGameQuit()), actionCollection());
+  gameHighscores = KStdGameAction::highscores(this, TQ_SLOT(slotGameHighscores()), actionCollection());
+  showMenuBar = KStdAction::showMenubar(this, TQ_SLOT(slotShowMenuBar()), actionCollection());
+  showToolBar = KStdAction::showToolbar(this, TQ_SLOT(slotShowToolBar()), actionCollection());
+  showStatusBar = KStdAction::showStatusbar(this, TQ_SLOT(slotShowStatusBar()), actionCollection());
   showMouseCursor = new TDEToggleAction(i18n("Show Mouse&cursor"), 0,
-                                      this, SLOT(slotShowMouseCursor()), actionCollection(),
+                                      this, TQ_SLOT(slotShowMouseCursor()), actionCollection(),
                                       "options_show_mousecursor");
   selectGraphicScheme = new TDEActionMenu(i18n("&Select graphic scheme"), actionCollection(),
   						                          "options_select_graphic_scheme");
-  KStdAction::keyBindings(this, SLOT(slotKeyBindings()), actionCollection());
+  KStdAction::keyBindings(this, TQ_SLOT(slotKeyBindings()), actionCollection());
   focusOutPause = new TDEToggleAction(i18n("Pause in &Background"), 0,
-                                    this, SLOT(slotFocusOutPause()), actionCollection(),
+                                    this, TQ_SLOT(slotFocusOutPause()), actionCollection(),
                                     "options_focus_out_pause");
   focusInContinue = new TDEToggleAction(i18n("Continue in &Foreground"), 0,
-                                      this, SLOT(slotFocusInContinue()), actionCollection(),
+                                      this, TQ_SLOT(slotFocusInContinue()), actionCollection(),
                                       "options_focus_in_continue");
 
   showMenuBar->setStatusText(i18n("Enables/disables the menubar"));
@@ -200,7 +200,7 @@ void TDEpacmanApp::readSchemes()
   schemesPopup->setAutoDelete(true);
 
   modesPopup = selectGraphicScheme->popupMenu();
-  connect(modesPopup, SIGNAL(activated(int)), this, SLOT(slotSchemeActivated(int)));
+  connect(modesPopup, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotSchemeActivated(int)));
 
   if (schemeCount == 0 || scheme == -1) {
     TQMessageBox::warning(this, i18n("Configuration Error"),
@@ -218,7 +218,7 @@ void TDEpacmanApp::readSchemes()
 
     TDEPopupMenu *p = new TDEPopupMenu;
     p->setCheckable(true);
-    connect(p, SIGNAL(activated(int)), this, SLOT(slotSchemeActivated(int)));
+    connect(p, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotSchemeActivated(int)));
     schemesPopup->append(p);
 
     modeID[m] = modesPopup->insertItem(description, schemesPopup->at(m));
