@@ -29,7 +29,7 @@
 #include <tqregexp.h>
 
 //include files for TDE
-#include <kapp.h>
+#include <tdeapplication.h>
 #include <tdemainwindow.h>
 #include <tdepopupmenu.h>
 #include <tdeaction.h>
